@@ -8,7 +8,7 @@ import struct
 
 import requests as rq
 
-from .abstract import ConnectIntf, IndexParam, CollectionSchema, TopKQueryResult2, PartitionParam
+from .abstract import ConnectIntf, IndexParam, CollectionSchema, PartitionParam
 from .check import is_legal_host, is_legal_port
 from .exceptions import NotConnectError, ParamError
 from .types import Status, IndexType, MetricType
@@ -615,7 +615,8 @@ class HttpHandler(ConnectIntf):
         response = rq.put(url, data, headers=headers)
 
         if response.status_code == 200:
-            return Status(), TopKQueryResult2(response)
+            pass
+            # return Status(), TopKQueryResult2(response)
 
         js = response.json()
         return Status(js["code"], js["message"]), None
@@ -637,7 +638,8 @@ class HttpHandler(ConnectIntf):
         response = rq.put(url, data, headers=headers, timeout=timeout)
 
         if response.status_code == 200:
-            return Status(), TopKQueryResult2(response)
+            pass
+            # return Status(), TopKQueryResult2(response)
 
         js = response.json()
         return Status(Status(js["code"], js["message"])), None
@@ -664,7 +666,8 @@ class HttpHandler(ConnectIntf):
         response = rq.put(url, data, headers=headers, timeout=timeout)
 
         if response.status_code == 200:
-            return Status(), TopKQueryResult2(response)
+            pass
+            # return Status(), TopKQueryResult2(response)
 
         js = response.json()
         return Status(Status(js["code"], js["message"])), None
