@@ -98,3 +98,39 @@ class MetricType(IntEnum):
 
     def __str__(self):
         return self._name_
+
+
+# class MetricType:
+#     INVALID = "INVALID"
+#     L2 = "L2"
+#     IP = "IP"
+#     HAMMING = "HAMMING"
+
+
+class DataType(IntEnum):
+    NULL = 0
+    BOOL = 1
+    # INT8 = 2
+    # INT16 = 3
+    INT32 = 4
+    INT64 = 5
+
+    FLOAT = 10
+    DOUBLE = 11
+
+    STRING = 20
+
+    BINARY_VECTOR = 100
+    FLOAT_VECTOR = 101
+    # VECTOR = 200
+
+    UNKNOWN = 999
+
+
+class RangeType(IntEnum):
+    LT = 0   # less than
+    LTE = 1  # less than or equal
+    EQ = 2   # equal
+    GT = 3   # greater than
+    GTE = 4  # greater than or equal
+    NE = 5   # not equal
